@@ -91,12 +91,20 @@ class AlertCreator:
 
     def _create_deviation_events_from_pandas(self, df: pd.DataFrame) -> List[List]:
         df.columns = ["deviation"]
-        df["timestamp"] = df.index.astype(np.int64)
+        df.loc[:, "timestamp"] = df.index.view(np.int64)
         # transform df into List
-        possible_events = []
+        possible_events: List[List] = []
         for i in df.itertuples():
-            possible_event = [int(i.Index.timestamp() * 1e3), i.deviation]
-            possible_events.append(possible_event)
+            # repeat previous deviation if the alert would be a one point alert
+            if (len(possible_events) > 0 and not i.deviation and possible_events[-1][1]) or (
+                len(possible_events) > 1 and possible_events[-1][1] and not possible_events[-2][1] and not i.deviation
+            ):
+                possible_event1 = [int(i.Index.timestamp() * 1e3), possible_events[-1][1]]
+                possible_event2 = [int(i.Index.timestamp() * 1e3), i.deviation]
+                possible_events.extend([possible_event1, possible_event2])
+            else:
+                possible_event = [int(i.Index.timestamp() * 1e3), i.deviation]
+                possible_events.append(possible_event)
         return possible_events
 
     def _validate_df(self, df):
