@@ -2,8 +2,26 @@ from typing import Union
 
 from cognite.client.data_classes import Asset, AssetList, TimeSeries, TimeSeriesList
 
+# Local Testing
+AIR_DATA_LOCAL_TESTING = "AIR_local_test"
 AIR_DATA_PATH_TO_YAML = "path_to_yaml"
 AIR_DATA_MODEL_NAME = "model_name"
+AIR_DATA_DEV_WRITE_BACK = "dev"
+AIR_DATA_BACKFILL_COMPLETED = "backfill_completed"
+AIR_DATA_BACKFILL_UNTIL = "backfilled_until"
+AIR_DATA_ALLOWED_KEYS = [
+    AIR_DATA_PATH_TO_YAML,
+    AIR_DATA_MODEL_NAME,
+    AIR_DATA_DEV_WRITE_BACK,
+    AIR_DATA_BACKFILL_COMPLETED,
+    AIR_DATA_BACKFILL_UNTIL,
+]
+AIR_LOCAL_TESTING_ERROR_MESSAGE = (
+    "Testing locally but cannot write back to Cognite Data Fusion."
+    + "\nSet 'dev'='True' in data parameter when testing locally."
+    + "\nVisit https://cognite-cognite-air-sdk.readthedocs-hosted.com/en/latest/#local-testing to learn"
+    + " more about local testing with the AIR SDK."
+)
 
 # Model- and schedule asset constants:
 SA_EXT_ID = "schedule_asset_ext_id"
