@@ -1,7 +1,11 @@
 from typing import Dict, List, Tuple, Union
 
+import pandas as pd
+
+from cognite.air import AIRClient
 from cognite.air.utils import is_string_truthy
 from cognite.client.data_classes import Event, EventList
+from cognite.client.exceptions import CogniteDuplicatedError, CogniteNotFoundError
 
 from .ts_utils import current_time_in_ms
 
@@ -29,7 +33,8 @@ def create_event_list(datapoints: List[List]) -> List[List[int]]:
 
 
     """
-
+    if len(datapoints) < 2:
+        return [[]]
     appended_datapoints: List[Tuple[List, List]] = list(zip(datapoints[:-1], datapoints[1:]))
     # change: either switch from False to True or the other way around
     only_changes: List[Tuple[List, List]] = list(filter(lambda x: x[0][1] != x[1][1], appended_datapoints))
@@ -292,3 +297,120 @@ def send_notification(start_time: int, end_time: int, alert_window: int, min_len
     is_event_fresh = end_time >= current_time_in_ms() - alert_window
     is_event_long = show_alert(start_time, end_time, min_length_of_alert)
     return is_event_fresh and is_event_long
+
+
+def update_events(client, events):
+    for event in events:
+        print(event.id)
+        try:
+            client.events.update(event)
+        except CogniteNotFoundError:
+            asset_ids = event.asset_ids
+            correct_asset_ids = []
+            for asset_id in asset_ids:
+                asset = client.assets.retrieve(asset_id)
+                if asset is not None:
+                    correct_asset_ids.append(asset.id)
+            event.asset_ids = correct_asset_ids
+            client.events.update(event)
+
+
+def create_alerts(
+    air_client: AIRClient,
+    df: pd.DataFrame,
+    end_point: int,
+    alert_window: int,
+    min_length_of_alert: int,
+    max_length_of_alert: int,
+    merge_period: int,
+    notification_message: str,
+    max_events_to_be_processed: int = -1,
+):
+    df.columns = ["deviation"]
+
+    # transform df into List
+    possible_events = []
+    for i in df.itertuples():
+        possible_event = [int(i.Index.timestamp() * 1e3), i.deviation]
+        possible_events.append(possible_event)
+    # create deviation events
+    deviation_events: List[List[int]] = create_event_list(possible_events)
+    # merge time intervals if necessary
+    merged_events = merge_time_intervals(
+        deviation_events, min_length_of_alert=min_length_of_alert, merge_period=merge_period
+    )
+    if air_client.backfilling.in_progress and len(merged_events) > max_events_to_be_processed:
+        merged_events = merged_events[:max_events_to_be_processed]
+        end_point = merged_events[-1][1]
+
+    # retrieve previous events and only keep open ones
+    previous_alerts_all = air_client.events.list_alerts(limit=0)
+    open_alerts = [alert for alert in previous_alerts_all if alert.end_time is None]
+
+    # close events
+    events_to_be_updated, new_events = close_event(
+        open_alerts,
+        merged_events,
+        end=end_point,
+        min_length_of_alert=min_length_of_alert,
+        merge_period=merge_period,
+    )
+    # check if events need to be updated and update
+    if len(events_to_be_updated) > 0:
+        print(f"trying to close {len(events_to_be_updated)} events.")
+        update_events(air_client._config.client, events_to_be_updated)
+        if len(new_events) == 0:
+            print("no new events")
+            return events_to_be_updated, [], end_point
+    # if there are no new events left return nothing
+    elif len(new_events) == 0:
+        print("nothing to write")
+        return [], [], end_point
+
+    # remove duplicates
+    non_duplicated_new_events = duplication_removal(new_events, previous_alerts_all)
+    non_duplicated_new_events = duplication_removal(non_duplicated_new_events, events_to_be_updated)
+
+    # if non duplicates exists create events
+    counter = 0
+    written_events = []
+    if len(non_duplicated_new_events) > 0:
+        print(f"trying to write {len(non_duplicated_new_events)} events.")
+        for event in non_duplicated_new_events:
+            ev = create_open_event(
+                event,
+                end=end_point,
+                notification_message=notification_message,
+                alert_window=alert_window,
+                min_length_of_alert=min_length_of_alert,
+                merge_period=merge_period,
+            )
+            # if event is not open and to short: ignore it
+            if ev.end_time is not None and ev.end_time - ev.start_time < min_length_of_alert:
+                continue
+            # if an event is open but ends before the end time is given
+            # and is shorter than min_length_of_alert: ignore it!
+            if (
+                ev.end_time is None
+                and int(ev.metadata["event_end"]) < end_point
+                and int(ev.metadata["event_end"]) - ev.start_time < min_length_of_alert
+            ):
+                continue
+            try:
+                air_client.events.create_alert(ev)
+                print(ev.id)
+                written_events.append([ev.start_time, ev.end_time or int(ev.metadata["event_end"])])
+                counter += 1
+            except CogniteDuplicatedError:
+                pass
+    print(f"Wrote {counter} Alerts")
+    return events_to_be_updated, written_events, end_point
+
+
+def duplication_removal(new_events: List, existing_alerts: List[Event]):
+    if len(new_events) == 0:
+        return new_events
+    non_duplicated_new_events = new_events
+    if len(existing_alerts) > 0:
+        non_duplicated_new_events = remove_duplicates([i for i in existing_alerts], non_duplicated_new_events)
+    return non_duplicated_new_events
